---
name: Bug report
about: Create a report to help us improve
title: ''
labels: Bug
assignees: abhinavsingh

---

**Check FAQs**
Please check [Frequently Asked Questions](https://github.com/abhinavsingh/proxy.py#frequently-asked-questions)
before opening a bug report.

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Run `proxy.py` as '...'
2. Do '...' to trigger error
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Version information**
 - OS: [e.g. iOS]
 - Browser [e.g. chrome, safari]
 - Device: [e.g. iPhone6]
 - proxy.py Version [e.g. 1.1.1]

**Additional context**
Add any other context about the problem here.

**Screenshots**
If applicable, add screenshots to help explain your problem.
